@@ -1,5 +1,6 @@
 # Imports do próprio módulo
-from inewave._utils.leitura import LeituraCSV
+from inewave._utils.leituracsv import LeituraCSV
+
 # Imports de módulos externos
 
 
@@ -17,8 +18,8 @@ class LeituraMediasSIN(LeituraCSV):
     tipos de dados, dentre outras tarefas necessárias para a leitura.
 
     """
-    def __init__(self,
-                 diretorio: str) -> None:
+
+    def __init__(self, diretorio: str) -> None:
         super().__init__(diretorio)
 
     def processa_dados_lidos(self):
@@ -31,5 +32,4 @@ class LeituraMediasSIN(LeituraCSV):
         cols_novas = [c.strip() for c in cols_atuais]
         self._dados.columns = cols_novas
         # Exclui a primeira e a última coluna (todos 0 | em branco)
-        self._dados.drop(columns=[cols_novas[0], cols_novas[-1]],
-                         inplace=True)
+        self._dados.drop(columns=[cols_novas[0], cols_novas[-1]], inplace=True)
